@@ -72,8 +72,6 @@ struct _RestProxyCallPrivate {
   GHashTable *response_headers;
   goffset length;
   gchar *payload;
-  guint status_code;
-  gchar *status_message;
 
   GCancellable *cancellable;
   gulong cancel_sig;
@@ -161,7 +159,6 @@ rest_proxy_call_finalize (GObject *object)
   g_free (priv->function);
 
   g_free (priv->payload);
-  g_free (priv->status_message);
 
   g_free (priv->url);
 
@@ -310,49 +307,18 @@ rest_proxy_call_add_header (RestProxyCall *call,
 
 }
 
-/**
- * rest_proxy_call_add_headers:
- * @call: The #RestProxyCall
- * @...: Header name and value pairs, followed by %NULL.
- *
- * Add the specified header name and value pairs to the call.  If a header
- * already exists, the new value will replace the old.
- */
 void
-rest_proxy_call_add_headers (RestProxyCall *call,
-                             ...)
+rest_proxy_call_take_header (RestProxyCall *call,
+                             const gchar   *header,
+                             gchar         *value)
 {
-  va_list headers;
+  RestProxyCallPrivate *priv = GET_PRIVATE (call);
 
   g_return_if_fail (REST_IS_PROXY_CALL (call));
 
-  va_start (headers, call);
-  rest_proxy_call_add_headers_from_valist (call, headers);
-  va_end (headers);
-}
-
-/**
- * rest_proxy_call_add_headers_from_valist:
- * @call: The #RestProxyCall
- * @headers: Header name and value pairs, followed by %NULL.
- *
- * Add the specified header name and value pairs to the call.  If a header
- * already exists, the new value will replace the old.
- */
-void
-rest_proxy_call_add_headers_from_valist (RestProxyCall *call,
-                                         va_list        headers)
-{
-  const gchar *header = NULL;
-  const gchar *value = NULL;
-
-  g_return_if_fail (REST_IS_PROXY_CALL (call));
-
-  while ((header = va_arg (headers, const gchar *)) != NULL)
-  {
-    value = va_arg (headers, const gchar *);
-    rest_proxy_call_add_header (call, header, value);
-  }
+  g_hash_table_insert (priv->headers,
+                       g_strdup (header),
+                       value);
 }
 
 /**
@@ -437,51 +403,6 @@ rest_proxy_call_add_param_full (RestProxyCall *call, RestParam *param)
   rest_params_add (GET_PRIVATE (call)->params, param);
 }
 
-/**
- * rest_proxy_call_add_params:
- * @call: The #RestProxyCall
- * @...: Parameter name and value pairs, followed by %NULL.
- *
- * Add the specified parameter name and value pairs to the call.  If a parameter
- * already exists, the new value will replace the old.
- */
-void
-rest_proxy_call_add_params (RestProxyCall *call,
-                            ...)
-{
-  va_list params;
-
-  g_return_if_fail (REST_IS_PROXY_CALL (call));
-
-  va_start (params, call);
-  rest_proxy_call_add_params_from_valist (call, params);
-  va_end (params);
-}
-
-/**
- * rest_proxy_call_add_params_from_valist:
- * @call: The #RestProxyCall
- * @params: Parameter name and value pairs, followed by %NULL.
- *
- * Add the specified parameter name and value pairs to the call.  If a parameter
- * already exists, the new value will replace the old.
- */
-void
-rest_proxy_call_add_params_from_valist (RestProxyCall *call,
-                                        va_list        params)
-{
-  const gchar *param = NULL;
-  const gchar *value = NULL;
-
-  g_return_if_fail (REST_IS_PROXY_CALL (call));
-
-  while ((param = va_arg (params, const gchar *)) != NULL)
-  {
-    value = va_arg (params, const gchar *);
-    rest_proxy_call_add_param (call, param, value);
-  }
-}
-
 /**
  * rest_proxy_call_lookup_param:
  * @call: The #RestProxyCall
@@ -552,7 +473,7 @@ _populate_headers_hash_table (const gchar *name,
 
 /* I apologise for this macro, but it saves typing ;-) */
 #define error_helper(x) g_set_error_literal(error, REST_PROXY_ERROR, x, message->reason_phrase)
-static gboolean
+static void
 _handle_error_from_message (SoupMessage *message, GError **error)
 {
   if (message->status_code < 100)
@@ -582,23 +503,23 @@ _handle_error_from_message (SoupMessage *message, GError **error)
         error_helper (REST_PROXY_ERROR_FAILED);
         break;
     }
-    return FALSE;
   }
-
-  if (message->status_code >= 200 && message->status_code < 300)
+  else if (message->status_code >= 200 && message->status_code < 300)
   {
-    return TRUE;
+    /* Good */
+    return;
+  }
+  else
+  {
+    /* If we are here we must be in some kind of HTTP error, lets try */
+    g_set_error_literal (error,
+                         REST_PROXY_ERROR,
+                         message->status_code,
+                         message->reason_phrase);
   }
-
-  /* If we are here we must be in some kind of HTTP error, lets try */
-  g_set_error_literal (error,
-                       REST_PROXY_ERROR,
-                       message->status_code,
-                       message->reason_phrase);
-  return FALSE;
 }
 
-static gboolean
+static void
 finish_call (RestProxyCall *call, SoupMessage *message, GError **error)
 {
   RestProxyCallPrivate *priv = GET_PRIVATE (call);
@@ -617,10 +538,7 @@ finish_call (RestProxyCall *call, SoupMessage *message, GError **error)
                             message->response_body->length + 1);
   priv->length = message->response_body->length;
 
-  priv->status_code = message->status_code;
-  priv->status_message = g_strdup (message->reason_phrase);
-
-  return _handle_error_from_message (message, error);
+  _handle_error_from_message (message, error);
 }
 
 static void
@@ -637,9 +555,6 @@ _continuous_call_message_completed_cb (SoupSession *session,
   call = closure->call;
   priv = GET_PRIVATE (call);
 
-  priv->status_code = message->status_code;
-  priv->status_message = g_strdup (message->reason_phrase);
-
   _handle_error_from_message (message, &error);
 
   closure->callback (closure->call,
@@ -1308,37 +1223,6 @@ rest_proxy_call_take_payload (RestProxyCall *call)
   return g_steal_pointer (&GET_PRIVATE (call)->payload);
 }
 
-/**
- * rest_proxy_call_get_status_code:
- * @call: The #RestProxyCall
- *
- * Get the HTTP status code for the call.
- */
-guint
-rest_proxy_call_get_status_code (RestProxyCall *call)
-{
-  g_return_val_if_fail (REST_IS_PROXY_CALL (call), 0);
-
-  return GET_PRIVATE (call)->status_code;
-}
-
-/**
- * rest_proxy_call_get_status_message:
- * @call: The #RestProxyCall
- *
- * Get the human-readable HTTP status message for the call.
- *
- * Returns: The status message. This string is owned by #RestProxyCall and
- * should not be freed.
- */
-const gchar *
-rest_proxy_call_get_status_message (RestProxyCall *call)
-{
-  g_return_val_if_fail (REST_IS_PROXY_CALL (call), NULL);
-
-  return GET_PRIVATE (call)->status_message;
-}
-
 /**
  * rest_proxy_call_serialize_params:
  * @call: The #RestProxyCall
